# -*- coding: utf-8 -*-

import logging

from django.conf import settings
from django.db import transaction
from django_logit import logit
from django_response import response
from django.db.models import Q

from TimeConvert import TimeConvert as tc

from account.models import UserInfo
from goods.models import GoodsInfo, PackInfo
from kol.models import KOLInfo
from pay.models import OrderInfo

logger = logging.getLogger('logit')

@logit(res=True)
@transaction.atomic
def order_list(request):
  kol_id = request.POST.get('kol_id', '')
  pack_id = request.POST.get('pack_id', '')
  ftime = request.POST.get('ftime', '')
  ttime = request.POST.get('ttime', '')
  query = request.POST.get('query', '')

  page = request.POST.get('page', 0)
  num = request.POST.get('num', 20)

  infos = OrderInfo.objects.filter(Q(phone__contains=query) | Q(name__contains=query) & Q(kol_id__contains=kol_id) & Q(pack_id__contains=pack_id)& Q(pay_status=1))

  res = []

  for info in infos:
    goods_info = []
    try:
      pack = PackInfo.objects.get(pack_id=info.pack_id)
      kol = KOLInfo.objects.get(kol_id=info.kol_id)

      for g in info.goods_info:
        try:
          goods = GoodsInfo.objects.get(good_id=g.get('good_id', ''))
          goods_info.append({
            'title': goods.title,
            'num': g.get('num', 0)
          })
        except:
          continue
      
      res.append({
        'name': info.name,
        'phone': info.phone,
        'address': info.address,
        'paid_at': tc.local_string(utc_dt=info.paid_at, format='%Y-%m-%d %H:%M'),
        'order_id': info.order_id,
        'transaction_id': info.transaction_id,
        'tracking_number': info.tracking_number,
        'goods_info': goods_info,
        'kol_name': kol.name,
        'pack_title': pack.title
      })
    except:
      continue
  
  return response(200, 'Order List Success', u'获取订单列表成功', {
        'orders': res
    })

@logit(res=True)
@transaction.atomic
def order_update(request):
    order_id = request.POST.get('order_id', '')
    tracking_number = request.POST.get('tracking_number', '')

    try:
      order = OrderInfo.objects.get(order_id=order_id)
      order.tracking_number = tracking_number
      order.save()
    except OrderInfo.DoesNotExist:
      return response(400001, 'Order Not Found', u'订单不存在')
    
    return response(200, 'Order Update Success', u'订单更新成功')